@@ -4,9 +4,17 @@ from MSApi.mixin import AttributeMixin, SalePricesMixin
 from MSApi.Assortment import Assortment
 from MSApi.ProductFolder import ProductFolder
 from MSApi.ObjectMS import check_init
+from MSApi.mixin.GenListMixin import GenerateListMixin
+from MSApi.mixin.RequestByIdMixin import RequestByIdMixin
+from MSApi.mixin.ProductfolderMixin import ProductfolderMixin
 
 
-class Product(Assortment, AttributeMixin, SalePricesMixin):
+class Product(Assortment,
+              AttributeMixin,
+              SalePricesMixin,
+              RequestByIdMixin,
+              GenerateListMixin,
+              ProductfolderMixin):
 
     _type_name = 'product'
 
@@ -20,14 +28,6 @@ class Product(Assortment, AttributeMixin, SalePricesMixin):
     def get_description(self) -> Optional[str]:
         return self._json.get('description')
 
-    @check_init
-    def get_productfolder(self) -> Optional[ProductFolder]:
-        """Группа Товара"""
-        result = self._json.get('productFolder')
-        if result is None:
-            return None
-        return ProductFolder(result)
-
     @check_init
     def get_variants_count(self) -> int:
         return int(self._json.get('variantsCount'))
