@@ -6,3 +6,6 @@ from MSApi.mixin.GenListMixin import *
 from MSApi.mixin.RequestByIdMixin import *
 from MSApi.mixin.StateMixin import *
 from MSApi.mixin.CreateNewMixin import *
+from MSApi.mixin.AccountIdMixin import *
+from MSApi.mixin.DescriptionMixin import *
+from MSApi.mixin.NameMixin import *
